Learn R Programming

rsdepth (version 0.1-4)

convexhull: Convex Hull of a pointset

Description

Convex Hull of a pointset in plane.

Usage

convexhull(x, y=NULL,...)

Arguments

x
The data as a matrix, data frame or list. If it is a matrix or data frame, then each row is viewed as one bivariate observation. If it is a list, all components must be numerical vectors of equal length (coordinates of observations).
y
The data as a matrix, data frame or list. If it is a matrix or data frame, then each row is viewed as one bivariate observation. If it is a list, all components must be numerical vectors of equal length (coordinates of observations).
...
For future use.

Value

  • Returns with respect to data set, ordered set of points on the convex hull.

concept

Convex Hull of a pointset

Details

In dimension 2, calculates Convex Hull of a pointset.

References

N. Mustafa, S. Ray, and M. Shabbir, Statistical Data Depth of Pointsets in the Plane,in prep..

See Also

inflate

Examples

Run this code
## calculation of centroid of a random pointset
z = matrix(rnorm(24),nc=2)
x = convexhull(z)

Run the code above in your browser using DataLab